@@ -804,7 +804,7 @@ class Test:
         self.expect(lambda: pat.match(u'\xe0'), "None")
         # String patterns.
         for flags in (0, regex.ASCII):
-            pat = regex.compile('\xc0', regex.IGNORECASE)
+            pat = regex.compile('\xc0', flags | regex.IGNORECASE)
             self.expect(lambda: pat.match('\xe0'), "None")
             pat = regex.compile('\w')
             self.expect(lambda: pat.match('\xe0'), "None")
