@@ -278,7 +278,7 @@ def _compile(pattern, flags=0):
     # Parse the regular expression.
     source = _rc._Source(pattern)
     info = _rc._Info(flags)
-    source.ignore_space = info.local_flags & VERBOSE
+    source.ignore_space = bool(info.local_flags & VERBOSE)
     parsed = _rc._parse_pattern(source, info)
     if not source.at_end():
         raise error("trailing characters in pattern")
@@ -300,14 +300,16 @@ def _compile(pattern, flags=0):
     # Optimise the parsed pattern.
     parsed = parsed.optimise(info)
     parsed = parsed.pack_characters()
+    reverse = bool(info.global_flags & REVERSE)
+    checks = parsed.get_checks(reverse)
+    parsed = _rc.prefix_checks(checks, parsed)
 
     # Should we print the parsed pattern?
     if flags & DEBUG:
-        parsed.dump()
+        parsed.dump(indent=0, reverse=reverse)
 
     # Compile the parsed pattern. The result is a list of tuples.
-    rev = (info.global_flags & REVERSE) != 0
-    code = parsed.compile(rev) + [(_rc._OP.SUCCESS, )]
+    code = parsed.compile(reverse) + [(_rc._OP.SUCCESS, )]
     if parsed.has_simple_start():
         fs_code = []
     else:
@@ -373,7 +375,7 @@ def _compile_replacement(pattern, template):
     return compiled
 
 if __name__ == "__main__":
-    _rc._create_header_file()
+    _rc._create_header_file(dir())
 else:
     import _regex
     _regex.set_exception(error)
