@@ -825,7 +825,7 @@ class Test:
         self.expect(lambda: pat.match('\xe0'), "None")
         # Bytes patterns.
         for flags in (0, regex.ASCII):
-            pat = regex.compile(b'\xc0', regex.IGNORECASE)
+            pat = regex.compile(b'\xc0', flags | regex.IGNORECASE)
             self.expect(lambda: pat.match(b'\xe0'), "None")
             pat = regex.compile(b'\w')
             self.expect(lambda: pat.match(b'\xe0'), "None")
